<?php
/**
 * @version		1.0
 * @package		mod_sig_slideshow
 * @copyright	Copyright (C) 2011 - 2012 Marcel Pol. All rights reserved.
 * @license		GNU General Public License version 2 or later; see LICENSE.txt
 */

// no direct access
defined('_JEXEC') or die;

abstract class modSIGSlideshowHelper {
	public static function getGallery(&$params) {

		// SIG Slideshow parameters
		$mod_name				= "mod_sig_slideshow";
		$moduleclass_sfx		= htmlspecialchars($params->get('moduleclass_sfx'));
		$category	 			= (int) $params->get('category', 0);
		$count		 			= (int) $params->get('count', 5);
		$cacheFolder			= 'cache/jw_simpleImageGallery';

		// JoomlaWorks parameters
		$plg_name				= "jw_simpleImageGallery";
		$plg_tag				= "gallery";

		$plugin = JPluginHelper::getPlugin('content', 'jw_simpleImageGallery');
		$pluginParams = new JRegistry();
		$pluginParams->loadString($plugin->params);
		$thb_width				= (int) $pluginParams->get('thb_width', 200);
		$thb_height				= (int) $pluginParams->get('thb_height', 160);
		$galleries_rootfolder	= $pluginParams->get('galleries_rootfolder','images');
		$smartResize			= $pluginParams->get('smartResize',true);
		$jpg_quality			= (int) $pluginParams->get('jpg_quality',80);
		$cache_expire_time		= (int) $pluginParams->get('cache_expire_time',36000);

		// expression to search for
		$regex = "#{".$plg_tag."}(.*?){/".$plg_tag."}#s";

		require_once JPATH_SITE.'/components/com_content/helpers/route.php';

		jimport('joomla.application.component.model');

		JModel::addIncludePath(JPATH_SITE.'/components/com_content/models', 'ContentModel');

		// Assign paths
		$sitePath = JPATH_SITE;
		$siteUrl  = JURI::base(true);

		// Check if plugin is enabled
		if (JPluginHelper::isEnabled('content',$plg_name) == false) {
			JError::raiseNotice('', JText::_('SIG_NPLUG'));
		}
		// Check for basic requirements
		if(!extension_loaded('gd') && !function_exists('gd_info')) {
			JError::raiseNotice('', JText::_('SIG_NGD'));
		}

		// Get the dbo for fetching the list of articles
		$db = JFactory::getDbo();

		// Get an instance of the generic articles model
		$model = JModel::getInstance('Articles', 'ContentModel', array('ignore_request' => true));

		// Set application parameters in model
		$app = JFactory::getApplication();
		$appParams = $app->getParams();
		$model->setState('params', $appParams);

		// Set the filters based on the module params
		$model->setState('list.start', 0);
		$model->setState('list.limit', (int) $params->get('count', 5));
		$model->setState('filter.published', 1);

		// Access filter
		$access = !JComponentHelper::getParams('com_content')->get('show_noauth');
		$authorised = JAccess::getAuthorisedViewLevels(JFactory::getUser()->get('id'));
		$model->setState('filter.access', $access);

		// Category filter
		$model->setState('filter.category_id', $params->get('category', array()));

		// Filter by language
		$model->setState('filter.language',$app->getLanguageFilter());

		// Set ordering
		$order_map = array(
			'm_dsc' => 'a.modified DESC, a.created',
			'mc_dsc' => 'CASE WHEN (a.modified = '.$db->quote($db->getNullDate()).') THEN a.created ELSE a.modified END',
			'c_dsc' => 'a.created',
			'p_dsc' => 'a.publish_up',
		);
		$ordering = JArrayHelper::getValue($order_map, $params->get('ordering'), 'a.publish_up');
		$dir = 'DESC';

		$model->setState('list.ordering', $ordering);
		$model->setState('list.direction', $dir);

		$items = $model->getItems();

		foreach ($items as $item) {
			// find all instances of the plugin and put them in $matches
			preg_match_all($regex,$item->introtext,$matches);

			$count = count($matches[0]); // Number of plugins

			if(!$count) continue; // No gallery found, try the next one

			// Process plugin tags
			if(preg_match_all($regex, $item->introtext, $matches, PREG_PATTERN_ORDER) > 0) {
				foreach ($matches[0] as $key => $match) {

					$tagcontent 		= preg_replace("/{.+?}/", "", $match);
					$tagparams 			= explode(':',$tagcontent);
					$galleryFolder	 	= $tagparams[0];

					// Gallery specific
					$srcimgfolder = $galleries_rootfolder.'/'.$galleryFolder.'/';
					$galleryID = substr(md5($key.$srcimgfolder),1,10); // create a unique 8-digit identifier for each gallery

					require_once JPATH_SITE.'/plugins/content/' . $plg_name . '/' . $plg_name . '/includes/helper.php';

					$gallery = SimpleImageGalleryHelper::renderGallery($srcimgfolder,$cacheFolder,$thb_width,$thb_height,$smartResize,$jpg_quality,$cache_expire_time);

					if(!$gallery){
						continue; // No gallery found, try the next one
					} else {
						break; // We have succes
					}
				}
				if(!$gallery){
					continue; // No gallery found, try the next one
				} else {
					break; // We have succes
				}
			}
		}
		if (isset($gallery)) {
			return $gallery;
		}
	}
}
?>
